@@ -9,19 +9,22 @@
 #' @return a survival plot corresponding to the psc fit
 #' @details This function plots the expected response of the control treatment
 #'    along with the observe response rates of the experimental arms
-#' @import ggplot2
+#' @import ggplot2 ggpubr
+#' @importFrom survival Surv survfit
 #' @examples
-#' bin.mod <- psc::bin.mod
-#' data <- psc::data
-#' bin.psc <- pscfit(bin.mod,data,nsim=3000)
-#' plot(bin.psc)
+#' e4_data <- psc::e4_data
+#' gemCFM <- psc::gemCFM
+#' psc <- pscfit(gemCFM,e4_data,nsim=1500,nchain=1)
+#' plot(psc)
 #' @export
-plot.psc <- function (x,...){
+plot.psc <- function (x, ...){
 
-  model.type <- x$'model.type';model.type
-  fam <- x$DC_clean$model_extract$family;fam
+  p <- NULL
+  model.type <- x$mod_class;model.type
+  fam <- x$family;fam
 
   if ("glm" %in% model.type) {
+
     ### gaussian
     if(fam$family%in%c("gaussian")){
       p <- plot.psc.cont(x)
@@ -42,4 +45,3 @@ plot.psc <- function (x,...){
   p
 }
 
-
